@@ -1,6 +1,6 @@
 package Getopt::Modular;
 {
-  $Getopt::Modular::VERSION = '0.10';
+  $Getopt::Modular::VERSION = '0.11';
 }
 
 #ABSTRACT: Modular access to Getopt::Long
@@ -14,7 +14,7 @@ use Scalar::Util qw(reftype looks_like_number);
 use Exception::Class
     'Getopt::Modular::Exception' => {
         description => 'Exception in commandline parsing/handling',
-        fields => [ qw(type option value warning) ],
+        fields => [ qw(type option value warning valid expected) ],
     },
     'Getopt::Modular::Internal' => {
         description => 'Internal Exception in commandline parsing/handling',
@@ -274,6 +274,16 @@ sub parseArgs
             $self->getOpt($opt);
         }
     }
+
+    # if passed in a hash ref to populate, fill it.
+    if (@_ && ref $_[0] eq 'HASH')
+    {
+        my $opts = shift;
+        for my $opt (keys %{$self->{accept_opts}})
+        {
+            $opts->{$opt} = $self->getOpt($opt);
+        }
+    }
 }
 
 
@@ -316,7 +326,10 @@ sub getOpt
     {
         if (wantarray)
         {
-            return ref $self->{options}{$opt} ? @{$self->{options}{$opt}} : $self->{options}{$opt};
+            return 
+                ref $self->{options}{$opt} eq 'ARRAY' ? @{$self->{options}{$opt}} : 
+                ref $self->{options}{$opt} eq 'HASH'  ? %{$self->{options}{$opt}} : 
+            $self->{options}{$opt};
         }
         return $self->{options}{$opt}
     }
@@ -354,7 +367,7 @@ sub _bool_val
 sub _int_val
 {
     my ($opt,$val) = @_;
-    if ($val =~ /\D/)
+    if ($val !~ /^[-+]?\d+$/)
     {
         Getopt::Modular::Exception->throw(
                                           message => "Trying to set '$opt' (an integer-only parameter) to '$val'",
@@ -494,7 +507,7 @@ sub setOpt
                                               ($self->_getType($opt) || 'SCALAR') .
                                               " got: " . (reftype $_[0] || 'SCALAR'),
                                               expected => ($self->_getType($opt) || 'SCALAR'),
-                                              opt => $opt,
+                                              option => $opt,
                                               value => $_[0],
                                              )
                 unless $self->_getType($opt) eq reftype $_[0];
@@ -571,7 +584,7 @@ sub getHelpRaw
             no warnings;
             # if it's not a code ref, the eval will exit, but we'll already
             # have what we want anyway.
-            $opt{valid_values} = $opt{valid_values}->();
+            $opt{valid_values} = [ $opt{valid_values}->() ];
         };
 
         # is it hidden?  It's still part of the raw output.
@@ -684,6 +697,7 @@ sub getHelpWrap
 1; # End of Getopt::Modular
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -692,7 +706,7 @@ Getopt::Modular - Modular access to Getopt::Long
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -1081,6 +1095,21 @@ will be used.
 Once all parameters have been accepted (and, possibly, unaccepted), you must
 call parseArgs to perform the actual parsing.
 
+Optionally, if you pass in a hash ref, it will be populated with every
+parameter.  This is intended to provide a stop-gap for migration from
+L<Getopt::Long>::GetOptions wherein you can provide your options hash
+and use that directly.
+
+    GM->parseArgs(\my %opts);
+
+The downside to this is that it will determine all values during parsing
+rather than deferring until the value is actually required.  Most of the
+time, this will be okay, but if some defaults take a long time to resolve
+or validate, e.g., network activities such as looking up users via LDAP,
+requesting a value from a wiki page, or even just reading a file over NFS,
+sshfs, Samba, or similar, that time will be wasted if the value isn't actually
+required during this execution based on other parameters.
+
 =head2 getOpt
 
 Retrieve the desired option.  This will "set" any option that has not
@@ -1288,10 +1317,9 @@ Darin McBride <dmcbride@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Darin McBride.
+This software is copyright (c) 2013 by Darin McBride.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
